# CLAUDE.md

This file provides guidance to Claude Code (claude.ai/code) when working with code in this repository.

## プロジェクトの目的

このリポジトリは、Claude Codeを効果的に使うための方法論と環境整備を探求するプロジェクトです。
特に、zsh/tmux/vim環境での統合、他のAIとの連携、MCP（Model Context Protocol）の活用に焦点を当てています。

## 主要機能

### 1. 拡張ヘルプシステム
- `/user:help` - カスタムヘルプ表示
- `/user:help/shortcuts` - キーボードショートカット詳細
- `/user:help/quickref` - クイックリファレンス
- `/user:help/safety` - 安全利用ガイド

### 2. AI統合機能
- `ai-import <file>` - ChatGPT会話のインポート
- `ai-compare <task>` - 複数AIでの比較検証
- `ai-chain <prompt>` - AIチェーン実行
- `ai-tmux` - AI作業用tmuxセッション

### 3. MCP（Model Context Protocol）
- ファイルシステム、GitHub、Docker等との統合
- カスタムMCPサーバーの実装
- Arch Linux / macOS固有のツール連携

### 4. ターミナル統合
- zsh拡張コマンド群
- tmux専用キーバインド
- vim統合機能

## 重要な参考資料

- `docs/advanced-setup.md` - 高度な設定ガイド
- `docs/guides/custom-commands.md` - カスタムコマンドの作成方法
- `docs/guides/archlinux-safety.md` - Arch Linux安全ガイド
- `docs/guides/custom-help-setup.md` - ヘルプシステムの設定

## セットアップ

### クイックセットアップ
```bash
# 全機能の一括設定
./setup-advanced.sh all

# 個別設定
./setup-advanced.sh zsh    # zsh統合
./setup-advanced.sh tmux   # tmux統合
./setup-advanced.sh mcp    # MCP設定
./setup-advanced.sh ai     # AI統合
```

### 手動セットアップ
```bash
# zsh設定の読み込み
source ./shell-config/.zshrc_claude

# カスタムヘルプのインストール
cp -r .claude/commands/* ~/.claude/commands/

# MCP設定
./mcp/setup-mcp.sh all
```

## 使用可能なコマンド

### Claude Code拡張コマンド
- `claude-analyze <file>` - ファイル解析
- `claude-review <file>` - コードレビュー
- `claude-test <file>` - テスト生成
- `claude-refactor <file>` - リファクタリング
- `claude-docs` - ドキュメント生成
- `claude-status` - 現在の作業状況を共有
- `claude-env` - 環境情報の共有

### AI統合コマンド
- `ai-import <chatgpt_log>` - ChatGPTログのインポート
- `ai-compare <task>` - 複数AIでの比較
- `ai-chain <prompt>` - AIチェーン実行
- `ai-tmux` - 専用tmuxセッション起動

### MCP関連コマンド
- `mcp-setup install` - MCPサーバーインストール
- `mcp-setup config` - 設定ファイル作成
- `mcp-setup test` - 動作テスト

## 開発方針

1. **コンテキストの継承**
   - 過去の会話ログを参考に、一貫した開発アプローチを維持
   - ChatGPTで培った知見をClaude Codeに引き継ぐ

2. **効果的なプロンプト戦略**
   - 明確で具体的な指示
   - 段階的なタスク分解
   - 適切なコンテキストの提供

3. **安全性の確保**
   - 危険なコマンドの実行前チェック
   - Docker/VM環境での隔離実行
   - 自動バックアップとスナップショット

## ディレクトリ構造

```
claude/
├── CLAUDE.md                 # このファイル
├── setup-advanced.sh        # 一括セットアップスクリプト
├── .claude/                  # Claude Code設定
│   └── commands/            # カスタムコマンド
├── docs/                    # ドキュメント
│   ├── guides/              # 各種ガイド
│   └── advanced-setup.md    # 高度な設定ガイド
├── scripts/                 # ユーティリティスクリプト
│   ├── ai-integration.sh    # AI統合機能
│   ├── claude-help.sh       # 拡張ヘルプ
│   └── *-safety-check.sh    # 安全チェック
├── mcp/                     # MCP設定
│   └── setup-mcp.sh         # MCPセットアップ
├── shell-config/            # シェル設定
│   └── .zshrc_claude        # zsh拡張設定
└── docker/                  # Docker環境
    └── archlinux/           # Arch Linux環境
```

## 対象環境

- **OS**: Arch Linux, macOS
- **シェル**: zsh
- **ターミナル**: tmux統合
- **エディタ**: vim/neovim統合
- **AI**: Claude Code + ChatGPT等の連携

## 注意事項

1. **セキュリティ**: 本番環境では安全チェック機能を有効化
2. **パフォーマンス**: 大規模なプロジェクトではDocker環境を推奨
3. **互換性**: 一部の機能はzsh/tmux特有の機能に依存

このリポジトリは、Claude Codeを中心とした現代的な開発環境の構築を目指しています。